# 奇遇科技 Django 开发辅助工具箱

![PyPI - Version](https://img.shields.io/pypi/v/django-qiyu-utils)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-qiyu-utils)
![PyPI - Downloads](https://img.shields.io/pypi/dm/django-qiyu-utils)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/django-qiyu-utils)
![GitHub repo size](https://img.shields.io/github/repo-size/qiyutechdev/django-qiyu-utils)
![Lines of code](https://img.shields.io/tokei/lines/github/qiyutechdev/django-qiyu-utils)

# WARNING

    USE IT AT YOUR OWN RISK!!
